@@ -180,6 +180,35 @@ class SetupHome(Command):
     def __str__(self):
         return 'setup_home'
 
+    @staticmethod
+    def _on_ci():
+        """
+            Detects if we are running on a CI system.
+            Returns the name of the CI system or None.
+        """
+        if os.environ.get('GITHUB_ACTIONS', False) == 'true':
+            return 'GitHub Actions'
+        elif os.environ.get('GITLAB_CI', False) == 'true':
+            return 'GitLab CI'
+        return None
+
+    @staticmethod
+    def _ssh_config_present():
+        """
+            Checks if any file in the .ssh dir exists or
+            any manual ssh config option is set.
+        """
+        ssh_vars = ['SSH_PRIVATE_KEY', 'SSH_PRIVATE_KEY_FILE', 'SSH_AUTH_SOCK']
+        if any(e in os.environ for e in ssh_vars):
+            return True
+
+        ssh_path = os.path.expanduser('~/.ssh')
+        if os.path.isdir(ssh_path):
+            with os.scandir(ssh_path) as it:
+                if any(it):
+                    return True
+        return False
+
     def _setup_netrc(self):
         if os.environ.get('NETRC_FILE', False):
             shutil.copy(os.environ['NETRC_FILE'],
@@ -222,9 +251,8 @@ class SetupHome(Command):
         gitconfig_host = os.environ.get('GITCONFIG_FILE', False)
         gitconfig_kas = self.tmpdirname + '/.gitconfig'
 
-        # when running in the github ci, always try to read the gitconfig
-        if not gitconfig_host and \
-           os.environ.get('GITHUB_ACTIONS', False) == 'true':
+        # on supported CI systems, always try to read the gitconfig
+        if not gitconfig_host and self._on_ci():
             gitconfig_host = os.path.expanduser('~/.gitconfig')
 
         if gitconfig_host and os.path.exists(gitconfig_host):
@@ -243,9 +271,23 @@ class SetupHome(Command):
                 if os.environ.get('GIT_CREDENTIAL_USEHTTPPATH', False):
                     config['credential']['useHttpPath'] = \
                         os.environ.get('GIT_CREDENTIAL_USEHTTPPATH')
+            # in GitLab CI, add ssh -> https rewrites if no config is present
+            ci_server = os.environ.get('CI_SERVER_HOST', False)
+            if self._on_ci() == 'GitLab CI' and ci_server and \
+                    not self._ssh_config_present() and \
+                    not os.path.exists(gitconfig_host):
+                logging.debug('Adding GitLab CI ssh -> https rewrites')
+                section = f'url "https://{ci_server}/"'
+                config.add_value(section, 'insteadOf',
+                                 f'git@{ci_server}:')
+                config.add_value(section, 'insteadOf',
+                                 f'ssh://git@{ci_server}/')
             config.write()
 
     def execute(self, ctx):
+        ci = self._on_ci()
+        if ci:
+            logging.info(f'Running on {ci}')
         def_umask = os.umask(0o077)
         self._setup_netrc()
         self._setup_gitconfig()
