@@ -23,6 +23,7 @@
     This module contains the core implementation of kas.
 """
 
+import argparse
 import re
 import os
 import sys
@@ -406,13 +407,19 @@ def ssh_no_host_key_check():
 
 
 def setup_parser_common_args(parser):
+    from kas.libcmds import Macro
+
     parser.add_argument('config',
                         help='Config file(s), separated by colon. Using '
                         '.config.yaml in KAS_WORK_DIR if none is specified.',
                         nargs='?')
     parser.add_argument('--skip',
-                        help='Skip build steps',
-                        default=[])
+                        help='Skip build steps. To skip more than one step, '
+                        'use this argument multiple times.',
+                        default=[],
+                        action='append',
+                        metavar='STEP',
+                        choices=[str(c) for c in Macro().setup_commands])
     parser.add_argument('--force-checkout', action='store_true',
                         help='Always checkout the desired commit/branch/tag '
                         'of each repository, discarding any local changes')
@@ -427,6 +434,48 @@ def setup_parser_preserve_env_arg(parser):
                         action='store_true')
 
 
+class ExtendConstAction(argparse._AppendConstAction):
+    """Add an 'extend_const' action similar to 'append_const'.
+
+    Based on the existing 'append_const' and 'extend' actions.
+    """
+    def __init__(self, option_strings, dest, const, default=None,
+                 required=False, help=None, metavar=None):
+        super(argparse._AppendConstAction, self).__init__(
+            option_strings=option_strings, dest=dest, nargs=0, const=const,
+            default=default, required=required, help=help, metavar=metavar)
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        items = getattr(namespace, self.dest, None)
+        if items is None:
+            items = []
+
+        if isinstance(items, list):
+            items = items[:]
+        else:
+            import copy
+            items = copy.copy(items)
+
+        items.extend(self.const)
+        setattr(namespace, self.dest, items)
+
+
+def setup_parser_keep_config_unchanged_arg(parser):
+    # Skip the tasks which would change the config of the build
+    # environment
+    steps = [
+        'setup_dir',
+        'finish_setup_repos',
+        'repos_apply_patches',
+        'write_bbconfig',
+    ]
+    parser.add_argument('-k', '--keep-config-unchanged',
+                        help='Skip steps that change the configuration',
+                        action=ExtendConstAction,
+                        dest='skip',
+                        const=steps)
+
+
 def run_handle_preserve_env_arg(ctx, os, args, SetupHome):
     if args.preserve_env:
         # Warn if there's any settings that setup_home would apply
