@@ -43,9 +43,11 @@ def load():
     from . import checkout
     from . import shell
     from . import menu
+    from . import dump
 
     register_plugins(build)
     register_plugins(checkout)
+    register_plugins(dump)
     register_plugins(for_all_repos)
     register_plugins(shell)
     register_plugins(menu)
