@@ -1,6 +1,6 @@
 # kas - setup tool for bitbake based projects
 #
-# Copyright (c) Siemens AG, 2017-2018
+# Copyright (c) Siemens AG, 2017-2024
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,24 +26,34 @@
     build environment and then invoke bitbake to build the targets selected
     in the chosen config file.
 
-    For example, to build the configuration described in the file
-    ``kas-project.yml`` you could run::
+    When running with ``--provenance <true|mode=...>`` kas will generate an
+    provenance attestation for the build. The attestation will be stored in
+    ``attestation/kas-build.provenance.json`` in the build directory.
+    For details about provenance, see the build attestation chapter.
 
-        kas build kas-project.yml
+    .. note::
+        In provenance mode, the command returns with a non-zero exit
+        code in case no artifact is found for at least one entry.
 """
 
 import logging
 import subprocess
 import sys
+import json
+from pathlib import Path
+from datetime import datetime
 from kas.context import create_global_context
 from kas.config import Config
 from kas.libkas import find_program, run_cmd
+from kas.libkas import setup_parser_keep_config_unchanged_arg
 from kas.libcmds import Macro, Command
 from kas.libkas import setup_parser_common_args
 from kas.kasusererror import CommandExecError
+from kas.attestation import Provenance, Statement
+
 
 __license__ = 'MIT'
-__copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
+__copyright__ = 'Copyright (c) Siemens AG, 2017-2024'
 
 
 class Build:
@@ -64,6 +74,7 @@ class Build:
         """
 
         setup_parser_common_args(parser)
+        setup_parser_keep_config_unchanged_arg(parser)
         parser.add_argument('extra_bitbake_args',
                             nargs='*',
                             help='Extra arguments to pass to bitbake '
@@ -73,6 +84,9 @@ class Build:
                             help='Select target to build')
         parser.add_argument('-c', '--cmd', '--task', dest='task',
                             help='Select which task should be executed')
+        parser.add_argument('--provenance',
+                            choices=['true', 'mode=min', 'mode=max'],
+                            help='Enable provenance attestation generation')
 
     def run(self, args):
         """
@@ -103,6 +117,21 @@ class BuildCommand(Command):
     def __str__(self):
         return 'build'
 
+    def _generate_attestation(self, ctx,
+                              time_started, time_finished,
+                              mode):
+        """
+            Generate the provenance attestation for the build.
+        """
+        predicate = Provenance(ctx, time_started, time_finished,
+                               mode)
+        stmt = Statement(predicate, ctx, time_started, time_finished).as_dict()
+        att_dir = Path(ctx.build_dir) / 'attestation'
+        att_dir.mkdir(parents=True, exist_ok=True)
+        with open(att_dir / 'kas-build.provenance.json', 'w') as f:
+            f.write(json.dumps(stmt, indent=4))
+            f.write('\n')
+
     def execute(self, ctx):
         """
             Executes the bitbake build command.
@@ -111,6 +140,8 @@ class BuildCommand(Command):
         bitbake = find_program(ctx.environ['PATH'], 'bitbake')
         cmd = [bitbake, '-c', ctx.config.get_bitbake_task()] \
             + self.extra_bitbake_args + ctx.config.get_bitbake_targets()
+
+        time_started = datetime.now()
         if sys.stdout.isatty():
             logging.info('%s$ %s', ctx.build_dir, ' '.join(cmd))
             ret = subprocess.call(cmd, env=ctx.environ, cwd=ctx.build_dir)
@@ -118,6 +149,12 @@ class BuildCommand(Command):
                 raise CommandExecError(cmd, ret)
         else:
             run_cmd(cmd, cwd=ctx.build_dir, liveupdate=True)
+        time_finished = datetime.now()
+
+        if ctx.args.provenance:
+            mode = Provenance.Mode.MAX if ctx.args.provenance == 'mode=max' \
+                else Provenance.Mode.MIN
+            self._generate_attestation(ctx, time_started, time_finished, mode)
 
 
 __KAS_PLUGINS__ = [Build]
