@@ -90,6 +90,9 @@ class Repo:
         self._patches = patches
         self.operations_disabled = disable_operations
 
+        if not self.url:
+            self.resolve_local()
+
     @property
     def layers(self):
         return [os.path.join(self.path, layer).rstrip(os.sep + '.')
@@ -135,6 +138,14 @@ class Repo:
             return branch
         return None
 
+    @property
+    def dirty(self):
+        if not self.url:
+            return True
+        (_, output) = run_cmd(self.is_dirty_cmd(),
+                              cwd=self.path, fail=False)
+        return bool(output)
+
     def __str__(self):
         if self.commit and (self.tag or self.branch):
             refspec = f'{self.commit}({self.tag or self.branch})'
@@ -226,7 +237,6 @@ class Repo:
 
         if url is None:
             # No version control operation on repository
-            url = path
             disable_operations = True
 
         if repo_type == 'git':
@@ -352,10 +362,7 @@ class RepoImpl(Repo):
 
         if not get_context().force_checkout:
             # Check if repos is dirty
-            (_, output) = run_cmd(self.is_dirty_cmd(),
-                                  cwd=self.path,
-                                  fail=False)
-            if output:
+            if self.dirty:
                 logging.warning('Repo %s is dirty - no checkout', self.name)
                 return
 
@@ -387,7 +394,9 @@ class RepoImpl(Repo):
                 raise RepoRefError(
                     f'Branch "{self.branch}" cannot be found '
                     f'in repository "{self.name}"')
-            if self.commit:
+            # check if branch contains the requested commit.
+            # skip check on shallow clones, as branch information is missing
+            if self.commit and not get_context().repo_clone_depth:
                 (_, output) = run_cmd(self.branch_contains_ref(),
                                       cwd=self.path,
                                       fail=False)
@@ -483,12 +492,30 @@ class RepoImpl(Repo):
 
         return 0
 
+    def resolve_local(self):
+        (retc, output) = run_cmd(self.get_remote_url_cmd(),
+                                 cwd=self.path, fail=False)
+        if retc == 0:
+            self.url = output.strip()
+
+        (retc, output) = run_cmd(self.get_commit_cmd(),
+                                 cwd=self.path, fail=False)
+        if retc == 0:
+            self.commit = output.strip()
+        if self.url and self.commit:
+            logging.debug('Repository %s resolved to %s @ %s',
+                          self.name, self.url, self.commit)
+
 
 class GitRepo(RepoImpl):
     """
         Provides the git functionality for a Repo.
     """
 
+    @staticmethod
+    def get_type():
+        return 'git'
+
     def remove_ref_prefix(self, ref):
         ref_prefix = 'refs/'
         return ref[ref.startswith(ref_prefix) and len(ref_prefix):]
@@ -498,6 +525,19 @@ class GitRepo(RepoImpl):
 
     def clone_cmd(self, srcdir, createref):
         cmd = ['git', 'clone', '-q']
+
+        depth = get_context().repo_clone_depth
+        if depth:
+            if self.refspec:
+                logging.warning('Shallow cloning is not supported for legacy '
+                                f'refspec on repository "{self.name}". '
+                                'Performing full clone.')
+            else:
+                cmd.extend(['--depth', str(depth)])
+                if self.branch:
+                    cmd.extend(['--branch',
+                                self.remove_ref_prefix(self.branch)])
+
         if createref:
             cmd.extend([self.effective_url, '--bare', srcdir])
         elif srcdir:
@@ -518,11 +558,22 @@ class GitRepo(RepoImpl):
 
     def fetch_cmd(self):
         cmd = ['git', 'fetch', '-q']
+
+        depth = 0 if self.refspec else get_context().repo_clone_depth
+        if depth:
+            cmd.extend(['--depth', str(depth)])
+
         if self.tag:
-            cmd.append('--tags')
+            cmd.extend(['origin', f'+{self.tag}:refs/tags/{self.tag}'])
+            return cmd
+
+        # only fetch this commit (branch information is lost)
+        if depth and self.commit:
+            cmd.extend(['origin', self.commit])
+            return cmd
 
         branch = self.branch or self.refspec
-        if branch and branch.startswith('refs/'):
+        if branch and (branch.startswith('refs/') or depth):
             branch = self.remove_ref_prefix(branch)
             cmd.extend(['origin', f'+{branch}:refs/remotes/origin/{branch}'])
 
@@ -563,12 +614,22 @@ class GitRepo(RepoImpl):
     def set_remote_url_cmd(self):
         return ['git', 'remote', 'set-url', 'origin', self.effective_url]
 
+    def get_remote_url_cmd(self):
+        return ['git', 'remote', 'get-url', 'origin']
+
+    def get_commit_cmd(self):
+        return ['git', 'rev-parse', '--verify', 'HEAD']
+
 
 class MercurialRepo(RepoImpl):
     """
         Provides the hg functionality for a Repo.
     """
 
+    @staticmethod
+    def get_type():
+        return 'mercurial'
+
     def add_cmd(self):
         return ['hg', 'add']
 
@@ -620,3 +681,9 @@ class MercurialRepo(RepoImpl):
 
     def set_remote_url_cmd(self):
         raise NotImplementedError()
+
+    def get_remote_url_cmd(self):
+        return ['hg', 'paths', 'default']
+
+    def get_commit_cmd(self):
+        return ['hg', 'log', '-r', '.', '--template', '{node}\n']
