@@ -20,7 +20,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-import os
 import shutil
 from kas import kas
 
@@ -30,20 +29,18 @@ LAYERBASE = '${TOPDIR}/..'
 
 
 @pytest.fixture
-def dokas(tmpdir):
+def dokas(monkeykas, tmpdir):
     tdir = str(tmpdir / 'test_layers')
     shutil.copytree('tests/test_layers', tdir)
-    os.chdir(tdir)
+    monkeykas.chdir(tdir)
     kas.kas(['shell', 'test.yml', '-c', 'true'])
-    yield
-    os.chdir(os.path.join(os.path.dirname(__file__), '..'))
 
 
 def test_layers_default(dokas):
     match = 0
     with open('build/conf/bblayers.conf', 'r') as f:
         for line in f:
-            if '{}/kas '.format(LAYERBASE) in line:
+            if f'{LAYERBASE}/kas ' in line:
                 match += 1
     assert match == 1
 
@@ -52,7 +49,7 @@ def test_layers_include(dokas):
     match = 0
     with open('build/conf/bblayers.conf', 'r') as f:
         for line in f:
-            if '{}/kas1/meta-'.format(LAYERBASE) in line:
+            if f'{LAYERBASE}/kas1/meta-' in line:
                 match += 1
     assert match == 2
 
@@ -60,11 +57,11 @@ def test_layers_include(dokas):
 def test_layers_exclude(dokas):
     with open('build/conf/bblayers.conf', 'r') as f:
         for line in f:
-            assert '{}/kas2'.format(LAYERBASE) not in line
+            assert f'{LAYERBASE}/kas2' not in line
 
 
 def test_layers_strip_dot(dokas):
     with open('build/conf/bblayers.conf', 'r') as f:
         lines = f.readlines()
-        assert any('{}/kas3 '.format(LAYERBASE) in x for x in lines)
-        assert any('{}/kas3/meta-bar'.format(LAYERBASE) in x for x in lines)
+        assert any(f'{LAYERBASE}/kas3 ' in x for x in lines)
+        assert any(f'{LAYERBASE}/kas3/meta-bar' in x for x in lines)
